@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 #
-# Copyright 2010-2020, Julian Catchen <jcatchen@illinois.edu>
+# Copyright 2010-2021, Julian Catchen <jcatchen@illinois.edu>
 #
 # This file is part of Stacks.
 #
@@ -100,7 +100,7 @@ close($log_fh);
 sub check_return_value {
     # $? is a 16 bit int. Exit code is given by `$? & 255` if the process was
     # terminated by a signal, and by `$? >> 8` if it exited normally.
-    my ($rv, $log_fh) = @_;
+    my ($rv, $log_fh, $last_cmd) = @_;
     if ($rv != 0) {
         my $code = ($rv >> 8) & 127;
         if ($rv & 255 || ($rv >> 8) > 127) {
@@ -118,7 +118,9 @@ sub check_return_value {
         }
         $msg .= ")";
         print $log_fh ($msg . ".\n");
-        print STDERR ($msg . "; see log file.\n");
+        print $log_fh "Last command executed by denovo_map.pl was:\n  $last_cmd\n";
+        print STDERR ($msg . "; see denovo_map.log file.\n");
+        print STDERR "Last command executed by denovo_map.pl was:\n  $last_cmd\n";
         exit 1;
     }
 }
@@ -179,14 +181,14 @@ sub execute_stacks {
                 push(@results, $_);
             }
             close($pipe_fh);
-            check_return_value($?, $log_fh);
+            check_return_value($?, $log_fh, $cmd);
 
             #
             # Pull the depth of coverage from ustacks.
             #
             my $depthline = (grep(/^Final coverage/, @results))[0];
-            my ($depth) = ($depthline =~ /mean=([^;]+)/);
-            push(@depths_of_cov, [$sample->{'file'}, $depth]);
+            my ($depth, $stdev, $max, $nreads, $pctreads) = ($depthline =~ /mean=([\d.]+); stdev=([\d.]+); max=(\d+); n_reads=(\d+)\(([\d.]+)%\)/);
+            push(@depths_of_cov, [$sample->{'file'}, $depth, $stdev, $max, $nreads, $pctreads]);
         }
 
         $i++;
@@ -250,7 +252,7 @@ sub execute_stacks {
                 if ($_ =~ /failed/i) { print STDERR "Catalog construction failed.\n"; exit(1); }
             }
             close($pipe_fh);
-            check_return_value($?, $log_fh);
+            check_return_value($?, $log_fh, $cmd);
         }
     }
 
@@ -280,7 +282,7 @@ sub execute_stacks {
                 print $log_fh $_;
             }
             close($pipe_fh);
-            check_return_value($?, $log_fh);
+            check_return_value($?, $log_fh, $cmd);
         }
     }
 
@@ -317,7 +319,7 @@ sub execute_stacks {
                 print $log_fh $_;
             }
             close($pipe_fh);
-            check_return_value($?, $log_fh);
+            check_return_value($?, $log_fh, $cmd);
         }
     }
 
@@ -342,7 +344,7 @@ sub execute_stacks {
                 print $log_fh $_;
             }
             close($pipe_fh);
-            check_return_value($?, $log_fh);
+            check_return_value($?, $log_fh, $cmd);
         }
     }
 
@@ -359,7 +361,7 @@ sub execute_stacks {
             print $log_fh $_;
         }
         close($pipe_fh);
-        check_return_value($?, $log_fh);
+        check_return_value($?, $log_fh, $cmd);
     }
 
     print STDERR  "denovo_map.pl is done.\n";
@@ -727,12 +729,19 @@ sub write_depths_of_cov {
     my ($depths, $log_fh) = @_;
 
     print STDERR "\nDepths of Coverage for Processed Samples:\n";
-    print $log_fh "\nDepths of Coverage for Processed Samples:\n";
+    
+    print $log_fh
+        "\nBEGIN cov_per_sample\n",
+        "# Depths of Coverage for Processed Samples\n",
+        "sample\tdepth of cov\tmax cov\tnumber reads incorporated\t% reads incorporated\n";
 
     foreach $a (@{$depths}) {
-        print STDERR  $a->[0], ": ", $a->[1], "x\n";
-        print $log_fh $a->[0], ": ", $a->[1], "x\n";
+        print STDERR  $a->[0], "; depth: ", $a->[1], "x; max: ", $a->[3], "x; number of reads: ", $a->[4], " (", $a->[5], "%)\n";
+        print $log_fh $a->[0], "\t", $a->[1], "\t", $a->[3], "\t", $a->[4], "\t", $a->[5], "\n";
     }
+
+    print $log_fh
+        "END cov_per_sample\n";
 }
 
 sub parse_command_line {
