@@ -48,22 +48,18 @@ public:
         SNPData() : tot_depth(0), gq(UINT8_MAX) {}
     };
 
-    int            id;            // Stack ID
-    int            merge_partner; // Stack ID of merged datum, if this datum was merged/phased from two, overlapping datums.
-    int            len;           // Length of locus
-    bool           corrected;     // Has this genotype call been corrected
-    char          *model;         // String representing SNP model output for each nucleotide at this locus.
-    char          *gtype;         // Genotype
-    char          *trans_gtype;   // Translated Genotype
-    char          *cigar;         // CIGAR string describing how the datum aligns to the catalog locus.
-    vector<char *> obshap;        // Observed Haplotypes
+    int             id;            // Stack ID
+    int             merge_partner; // Stack ID of merged datum, if this datum was merged/phased from two, overlapping datums.
+    int             len;           // Length of locus
+    char           *model;         // String representing SNP model output for each nucleotide at this locus.
+    char           *gtype;         // Mapping genotype
+    char           *cigar;         // CIGAR string describing how the datum aligns to the catalog locus.
+    vector<char *>  obshap;        // Observed Haplotypes
     vector<SNPData> snpdata;
 
     Datum()  {
         this->id            = -1;
-        this->corrected     = false;
         this->gtype         = NULL;
-        this->trans_gtype   = NULL;
         this->model         = NULL;
         this->cigar         = NULL;
         this->len           = 0;
@@ -73,10 +69,17 @@ public:
         for (uint i = 0; i < this->obshap.size(); i++)
             delete [] this->obshap[i];
         delete [] this->gtype;
-        delete [] this->trans_gtype;
         delete [] this->model;
         delete [] this->cigar;
     }
+    
+    void genotype(string g) {
+        if (g.length() == 0) return;
+        if (this->gtype != NULL) delete [] this->gtype;
+        this->gtype = new char [g.length() + 1];
+        strcpy(this->gtype, g.c_str());
+    }
+    string genotype() { return string(this->gtype); }
 };
 
 template<class LocusT=Locus>
@@ -393,6 +396,7 @@ PopMap<LocusT>::populate_external(
     const vector<size_t>& sample_vcf_i_to_mpopi_i
 ) { try {
     assert(vcf_record.is_snp());
+    assert(vcf_record.count_alleles() == 2);
     assert(sample_vcf_i_to_mpopi_i.size() == vcf_header.samples().size());
     // We ignore the '*' allele & treat samples that have it as missing.
     long upstream_del_allele = -1;
