@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2011-2018, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2011-2021, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -21,10 +21,6 @@
 //
 // clean.cc -- common routines for processing and cleaning raw seqeunce data.
 //
-// Julian Catchen
-// jcatchen@uoregon.edu
-// University of Oregon
-//
 
 #include "clean.h"
 
@@ -237,19 +233,30 @@ parse_input_record(Seq *s, RawRead *r)
                     strncpy(r->index_bc, p, lim);
                     r->index_bc[lim] = '\0';
                     break;
+                case null_index:
+		    if (*z == '+')
+			p = z + 1;
+		    for (z = p; *z != '\0'; z++);
+		    lim = z - p;
+		    lim = lim < max_bc_size_1 ? lim : max_bc_size_1;
+		    strncpy(r->index_bc, p,  lim);
+                    r->index_bc[lim] = '\0';
+                    break;		    
                 default:
                     break;
                 }
             } else if (r->read == 2) {
                 if (*z == '+')
                     p = z + 1;
+		for (z = p; *z != '\0'; z++);
+		lim = z - p;
 
                 switch (barcode_type) {
-                case null_index:
                 case index_index:
                 case inline_index:
-                    strncpy(r->index_bc, p,  max_bc_size_2);
-                    r->index_bc[max_bc_size_2] = '\0';
+		    lim = lim < max_bc_size_2 ? lim : max_bc_size_2;
+                    strncpy(r->index_bc, p,  lim);
+                    r->index_bc[lim] = '\0';
                     break;
                 default:
                     break;
