@@ -52,11 +52,11 @@ class Export {
     virtual int  open(const MetaPopInfo *) = 0;
     virtual int  write_header()    = 0;
     virtual int  write_batch(const vector<LocBin *> &) = 0;
-    virtual int  post_processing() {return 0;}
-    virtual void close()           {this->_fh.close();}
+    virtual int  post_processing() { return 0; }
+    virtual void close()           { this->_fh.close(); }
 
-    bool is_hap_export();
-    string tmp_path() const {return this->_path + ".part";}
+    bool       is_hap_export();
+    string     tmp_path() const { return this->_path + ".part"; }
     static int transpose(ifstream &ifh, vector<string> &transposed);
 };
 
@@ -193,6 +193,7 @@ class HapDivergenceExport: public Export {
     ~HapDivergenceExport() {
         for (uint i = 0; i < this->_fhs.size(); i++)
             delete this->_fhs[i];
+	delete this->_metapop_fh;
     }
     int  open(const MetaPopInfo *mpopi);
     int  write_header();
@@ -201,10 +202,28 @@ class HapDivergenceExport: public Export {
     void close() {
         for (uint i = 0; i < this->_fhs.size(); i++)
             this->_fhs[i]->close();
+	this->_metapop_fh->close();
         return;
     }
 };
 
+class BSArchiveExport: public Export {
+    //
+    // Output an archive of our computed population genetics statistics
+    // for later use in bootstrapping operations.
+    //
+    const MetaPopInfo *_mpopi;
+    uint  _pop_cnt;
+
+ public:
+    BSArchiveExport() : _mpopi(NULL), _pop_cnt(UINT_MAX) {}
+    ~BSArchiveExport() {}
+    int  open(const MetaPopInfo *mpopi);
+    int  write_header();
+    int  write_batch(const vector<LocBin *> &);
+    int  write_batch_pairwise(const vector<LocBin *> &, const vector<vector<HapStat *>> &, const vector<vector<PopPair **>> &);
+};
+
 class PlinkExport: public OrderableExport {
     const MetaPopInfo *_mpopi;
     ofstream _tmpfh;
