@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2014-2017, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2014-2021, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -48,15 +48,15 @@ public:
     Ordered(): incompatible_sites(0), total_sites(0), uniq_sites(0), multiple_sites(0) {}
     virtual ~Ordered() {}
 
-    int init_sites(vector<const StatT *> &, map<uint, uint> &, const vector<LocBin *> &);
-    int init_sites(vector<const StatT *> &, map<uint, uint> &, const vector<LocBin *> &, uint);
-    int init_sites(vector<const StatT *> &, map<uint, uint> &, const vector<LocBin *> &, uint, uint);
-    int init_haplotypes(vector<const StatT *> &, map<uint, uint> &, const vector<LocBin *> &);
+    int init_sites(vector<StatT *> &, map<uint, uint> &, const vector<LocBin *> &);
+    int init_sites(vector<StatT *> &, map<uint, uint> &, const vector<LocBin *> &, uint);
+    int init_sites(vector<StatT *> &, map<uint, uint> &, const vector<LocBin *> &, uint, uint);
+    int init_haplotypes(vector<StatT *> &, map<uint, uint> &, const vector<LocBin *> &);
 };
 
 template<class StatT>
 int
-Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci)
+Ordered<StatT>::init_sites(vector<StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci)
 {
     const CSLocus  *loc;
     const LocTally *ltally;
@@ -97,7 +97,7 @@ Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_
 
 template<class StatT>
 int
-Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci, uint pop_id)
+Ordered<StatT>::init_sites(vector<StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci, uint pop_id)
 {
     const CSLocus *loc;
     const LocSum  *lsum;
@@ -113,7 +113,7 @@ Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_
         lsum = sorted_loci[pos]->s->per_pop(pop_id);
 
         for (uint k = 0; k < loc->len; k++) {
-            if (lsum->nucs[k].num_indv > 0) 
+            if (lsum->nucs[k].num_indv() > 0) 
                 bps.push_back(lsum->nucs[k].bp);
         }
     }
@@ -139,7 +139,7 @@ Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_
 
 template<class StatT>
 int
-Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci, uint pop_id_1, uint pop_id_2)
+Ordered<StatT>::init_sites(vector<StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci, uint pop_id_1, uint pop_id_2)
 {
     const CSLocus *loc;
     const LocSum  *lsum_1, *lsum_2;
@@ -155,8 +155,8 @@ Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_
         lsum_2 = sorted_loci[pos]->s->per_pop(pop_id_2);
 
         for (uint k = 0; k < loc->len; k++) {
-            if (lsum_1->nucs[k].num_indv > 0 &&
-                lsum_2->nucs[k].num_indv > 0)
+            if (lsum_1->nucs[k].num_indv() > 0 &&
+                lsum_2->nucs[k].num_indv() > 0)
                 bps.push_back(lsum_1->nucs[k].bp);
         }
     }
@@ -182,7 +182,7 @@ Ordered<StatT>::init_sites(vector<const StatT *> &sites, map<uint, uint> &sites_
 
 template<class StatT>
 int
-Ordered<StatT>::init_haplotypes(vector<const StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci)
+Ordered<StatT>::init_haplotypes(vector<StatT *> &sites, map<uint, uint> &sites_key, const vector<LocBin *> &sorted_loci)
 {
     const CSLocus *loc;
     int         bp;
@@ -219,13 +219,13 @@ class OHaplotypes: public Ordered<StatT> {
 public:
     OHaplotypes(): Ordered<StatT>() { }
 
-    int order(vector<const StatT *> &, const vector<LocBin *> &);
-    int order(vector<const StatT *> &, const vector<LocBin *> &, const vector<StatT *> &);
+    int order(vector<StatT *> &, const vector<LocBin *> &);
+    int order(vector<StatT *> &, const vector<LocBin *> &, const vector<StatT *> &);
 };
 
 template<class StatT>
 int
-OHaplotypes<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &sorted_loci)
+OHaplotypes<StatT>::order(vector<StatT *> &sites, const vector<LocBin *> &sorted_loci)
 {
     map<uint, uint> sites_key;
 
@@ -236,7 +236,7 @@ OHaplotypes<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &
 
 template<class StatT>
 int
-OHaplotypes<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &sorted_loci, const vector<StatT *> &div)
+OHaplotypes<StatT>::order(vector<StatT *> &sites, const vector<LocBin *> &sorted_loci, const vector<StatT *> &div)
 {
     StatT *pair;
     map<uint, uint> sites_key;
@@ -262,12 +262,12 @@ public:
         this->log_fh = &log_fh;
     }
 
-    bool order(vector<const StatT *> &, const vector<LocBin *> &, const vector<StatT **> &);
+    bool order(vector<StatT *> &, const vector<LocBin *> &, const vector<StatT **> &);
 };
 
 template<class StatT>
 bool
-OPopPair<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &sorted_loci, const vector<StatT **> &div)
+OPopPair<StatT>::order(vector<StatT *> &sites, const vector<LocBin *> &sorted_loci, const vector<StatT **> &div)
 {
     CSLocus *loc;
     StatT  **pair;
@@ -334,12 +334,12 @@ public:
         this->log_fh = &log_fh;
     }
 
-    int order(vector<const StatT *> &, const vector<LocBin *> &, uint);
+    int order(vector<StatT *> &, const vector<LocBin *> &, uint);
 };
 
 template<class StatT>
 int
-OSumStat<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &sorted_loci, uint pop_id)
+OSumStat<StatT>::order(vector<StatT *> &sites, const vector<LocBin *> &sorted_loci, uint pop_id)
 {
     this->incompatible_sites = 0;
     this->total_sites        = 0;
@@ -363,7 +363,7 @@ OSumStat<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &sor
         lsum = sorted_loci[pos]->s->per_pop(pop_id);
 
         for (uint k = 0; k < loc->len; k++) {
-            if (lsum->nucs[k].num_indv == 0) continue;
+            if (lsum->nucs[k].num_indv() == 0) continue;
 
             assert(sites_key.count(lsum->nucs[k].bp) > 0);
             this->total_sites++;
@@ -372,6 +372,7 @@ OSumStat<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &sor
                 sites[sites_key[lsum->nucs[k].bp]] = &(lsum->nucs[k]);
             } else {
                 this->multiple_sites++;
+		// cerr << "Overlapping site for locus " << loc->id << " at " << loc->loc.chr() << ", " << lsum->nucs[k].bp << "\n";
             }
         }
     }
@@ -389,12 +390,12 @@ public:
         this->log_fh = NULL;
     }
 
-    int order(vector<const StatT *> &, const vector<LocBin *> &);
+    int order(vector<StatT *> &, const vector<LocBin *> &);
 };
 
 template<class StatT>
 int
-OLocTally<StatT>::order(vector<const StatT *> &sites, const vector<LocBin *> &sorted_loci)
+OLocTally<StatT>::order(vector<StatT *> &sites, const vector<LocBin *> &sorted_loci)
 {
     this->incompatible_sites = 0;
     this->total_sites        = 0;
