@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2011-2018, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2011-2021, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -172,6 +172,7 @@ int main (int argc, char* argv[]) {
         counters[files[i].first]["ambiguous"]    = 0;
         counters[files[i].first]["retained"]     = 0;
         counters[files[i].first]["recovered"]    = 0;
+	counters[files[i].first]["transposed"]   = 0;
 
         if (paired) {
             if (out_file_type == FileT::gzfastq || out_file_type == FileT::gzfasta)
@@ -343,17 +344,28 @@ process_paired_reads(string prefix_1,
         // If a BestRAD protocol was used, check which read the barcode/restriction cutsite is on
         // and transpose the reads if necessary.
         //
-        if (bestrad) {
-            if (check_for_transposed_reads(r_1, r_2, renz_1))
+        if (bestrad)
+            if (check_for_transposed_reads(r_1, r_2, renz_1)) {
                 transpose_reads(&r_1, &r_2);
-        }
+		counter["transposed"]++;
+	    }
 
-        if (barcode_type != null_null &&
-            barcode_type != inline_null &&
-            barcode_type != index_null)
-            bc.set(r_1->se_bc, r_2->pe_bc);
-        else if (barcode_type != null_null)
-            bc.set(r_1->se_bc);
+	switch (barcode_type) {
+	case inline_null:
+        case index_null:
+        case null_index:
+	    bc.set(r_1->se_bc);
+	    break;
+        case index_inline:
+	case inline_index:
+	case inline_inline:
+	case index_index:
+	    bc.set(r_1->se_bc, r_2->pe_bc);
+            break;
+	case null_null:
+        default:
+            break;
+	}
 
         process_barcode(r_1, r_2, bc, pair_1_fhs, se_bc, pe_bc, barcode_log, counter);
 
@@ -917,12 +929,22 @@ print_results(int argc, char **argv,
 
     init_log(log, argc, argv);
 
-    log << "File\t"
+    log << "\n"
+	<< "# Note: Individual distributions can be extracted using the `stacks-dist-extract` utility.\n"
+	<< "#       e.g. `stacks-dist-extract "
+	<< log_path.c_str() + (log_path.find_last_of('/') + 1)
+	<<" dist_name`\n";
+
+    log << "\n"
+	<< "BEGIN per_file_raw_read_counts" << "\n"
+	<< "File\t"
         << "Retained Reads\t";
     if (filter_illumina)
         log << "Illumina Filtered\t";
     if (filter_adapter)
         log << "Adapter Seq" << "\t";
+    if (bestrad)
+	log << "Transposed Reads" << "\t";
     log << "Low Quality\t"
         << "Barcode Not Found\t"
         << "RAD cutsite Not Found\t"
@@ -935,12 +957,15 @@ print_results(int argc, char **argv,
             log << it->second["ill_filtered"] << "\t";
         if (filter_adapter)
             log << it->second["adapter"] << "\t";
+	if (bestrad)
+	    log << it->second["transposed"] << "\t";
         log << it->second["low_quality"] << "\t"
             << it->second["ambiguous"]   << "\t"
             << it->second["noradtag"]    << "\t"
             << it->second["total"]       << "\n";
     }
-
+    log << "END per_file_raw_read_counts" << "\n";
+    
     map<string, long> c;
     c["total"]        = 0;
     c["low_quality"]  = 0;
@@ -948,7 +973,8 @@ print_results(int argc, char **argv,
     c["ill_filtered"] = 0;
     c["ambiguous"]    = 0;
     c["noradtag"]     = 0;
-
+    c["transposed"]   = 0;
+    
     //
     // Total up the individual counters
     //
@@ -960,6 +986,7 @@ print_results(int argc, char **argv,
         c["ambiguous"]    += it->second["ambiguous"];
         c["noradtag"]     += it->second["noradtag"];
         c["retained"]     += it->second["retained"];
+	c["transposed"]   += it->second["transposed"];
     }
 
     auto print_nreads = [&c] (long n, const string& legend) {
@@ -969,6 +996,8 @@ print_results(int argc, char **argv,
     };
 
     cerr << c["total"] << " total sequences\n";
+    if (bestrad)
+	print_nreads(c["transposed"], "reads were transposed [based on the BestRAD flag]");
     if (filter_illumina)
         print_nreads(c["ill_filtered"], "failed Illumina filtered reads");
     if (filter_adapter)
@@ -978,8 +1007,11 @@ print_results(int argc, char **argv,
     print_nreads(c["noradtag"], "RAD cutsite not found drops");
     print_nreads(c["retained"], "retained reads");
 
-    log        << "\n"
+    log  << "\n"
+	 << "BEGIN total_raw_read_counts" << "\n"
          << "Total Sequences\t"      << c["total"]       << "\n";
+    if (bestrad)
+        log << "Transposed reads\t" << c["transposed"] << "\n";
     if (filter_illumina)
         log << "Failed Illumina filtered reads\t" << c["ill_filtered"] << "\n";
     if (filter_adapter)
@@ -987,7 +1019,8 @@ print_results(int argc, char **argv,
     log << "Barcode Not Found\t"     << c["ambiguous"]   << "\n"
         << "Low Quality\t"           << c["low_quality"] << "\n"
         << "RAD Cutsite Not Found\t" << c["noradtag"]    << "\n"
-        << "Retained Reads\t"        << c["retained"]    << "\n";
+        << "Retained Reads\t"        << c["retained"]    << "\n"
+	<< "END total_raw_read_counts" << "\n";
 
     if (max_bc_size_1 == 0) return 0;
 
@@ -1005,13 +1038,14 @@ print_results(int argc, char **argv,
     // Print out barcode information.
     //
     log << "\n"
-        << "Barcode\t";
+        << "BEGIN per_barcode_raw_read_counts" << "\n"
+	<< "Barcode\t";
     if (bc_names)
         log << "Filename\t";
     log << "Total\t"
-        << "NoRadTag\t"
-        << "LowQuality\t"
-        << "Retained\n";
+        << "RAD Cutsite Not Found\t"
+        << "Low Quality\t"
+        << "Retained Reads\n";
 
     set<BarcodePair> barcode_list;
 
@@ -1031,8 +1065,10 @@ print_results(int argc, char **argv,
                 << barcode_log[barcodes[i]]["retained"] << "\n";
     }
 
-    log << "\n"
-        << "Sequences not recorded\n"
+    log << "END per_barcode_raw_read_counts" << "\n"
+	<< "\n"
+        << "BEGIN barcodes_not_recorded" << "\n"
+	<< "# A list and count of barcodes found that were not specified in the barcodes input file.\n"
         << "Barcode\t"
         << "Total\n";
 
@@ -1053,6 +1089,8 @@ print_results(int argc, char **argv,
             << bcs[i].second << "\n";
     }
 
+    
+    log << "END barcodes_not_recorded" << "\n";
     log.close();
 
     return 0;
@@ -1409,8 +1447,8 @@ void help() {
          << "  f: path to the input file if processing single-end sequences.\n"
          << "  1: first input file in a set of paired-end sequences.\n"
          << "  2: second input file in a set of paired-end sequences.\n"
-         << "  c,--clean: clean data, remove any read with an uncalled base.\n"
-         << "  q,--quality: discard reads with low quality scores.\n"
+         << "  c,--clean: clean data, remove any read with an uncalled base ('N').\n"
+         << "  q,--quality: discard reads with low quality (phred) scores.\n"
          << "  r,--rescue: rescue barcodes and RAD-Tags.\n"
          << "  t: truncate final read length to this value.\n"
          << "  D: capture discarded reads to a file.\n"
@@ -1463,7 +1501,7 @@ void help() {
          << "    --merge: if no barcodes are specified, merge all input files into a single output file.\n\n"
          << "  Advanced options:\n"
          << "    --filter-illumina: discard reads that have been marked by Illumina's chastity/purity filter as failing.\n"
-         << "    --disable-rad-check: disable checking if the RAD site is intact.\n"
+         << "    --disable-rad-check: disable checking if the RAD cut site is intact.\n"
          << "    --len-limit <limit>: specify a minimum sequence length (useful if your data has already been trimmed).\n"
          << "    --barcode-dist-1: the number of allowed mismatches when rescuing single-end barcodes (default 1).\n"
          << "    --barcode-dist-2: the number of allowed mismatches when rescuing paired-end barcodes (defaults to --barcode-dist-1).\n";
