@@ -92,6 +92,8 @@ const char *ncoI[]    = {"CATGG",             // C/CATGG, NcoI
                          "CCATG"};
 const char *ndeI[]    = {"TATG",              // CA/TATG, NdeI
                          "CATA"};
+const char *ngoMIV[]  = {"CCGGC"              // G/CCGGC, NgoMIV
+                         "GCCGG"};
 const char *nheI[]    = {"CTAGC",             // G/CTAGC, NheI
                          "GCTAG"};
 const char *nlaIII[]  = {"CATG",              // CATG, NlaIII
@@ -190,6 +192,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz["pacI"]    = pacI;    // AAT/TAATT, PacI
     renz["pspXI"]   = pspXI;   // VC/TCGAGB, PspXI
     renz["hpyCH4IV"] = hpyCH4IV; // A/CGT, HpyCH4IV
+    renz["ngoMIV"]   = ngoMIV;   // G/CCGGC, NgoMIV    
 
     renz_cnt["sbfI"]    = 1;
     renz_cnt["pstI"]    = 1;
@@ -247,6 +250,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_cnt["pacI"]    = 1;
     renz_cnt["pspXI"]   = 3;
     renz_cnt["hpyCH4IV"] = 1;
+    renz_cnt["ngoMIV"]  = 1;
     
     renz_len["sbfI"]    = 6;
     renz_len["pstI"]    = 5;
@@ -304,6 +308,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_len["pacI"]    = 5;
     renz_len["pspXI"]   = 6;
     renz_len["hpyCH4IV"] = 3;
+    renz_len["ngoMIV"]  = 5;
 }
 
 void
