@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010-2020, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2010-2021, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -64,6 +64,10 @@ int main (int argc, char* argv[]) {
     // Set the number of OpenMP parallel threads to execute.
     //
     #ifdef _OPENMP
+    if (num_threads > max_threads) {
+	cerr << "Warning: too many threads requested and performance will be negatively affected; reducing thread count to " << max_threads << ".\n";
+	num_threads = max_threads;
+    }
     omp_set_num_threads(num_threads);
     #endif
 
